/*
 * RCWController SAMPLE Program
 * ESP-WROOM-2 & WALLBOT
 * 2016/2/18 by Michio Ono
 * http://rcwcontroller.micutil.com
 */
 
#include <ESP8266WiFi.h>
#include <WiFiUdp.h>
#include "TB6612FNG.h"
                      // ESP          LPC1768
#define Left_PWM  12  // PIN4   <->   PIN21
#define Left_FWD  14  // PIN3   <->   
#define Left_REV  15  // PIN6   <->
#define Rght_PWM  13  // PIN5   <->   PIN22
#define Rght_FWD  4   // PIN10  <->
#define Rght_REV  5   // PIN14  <->
                      // PIN18  <->   PIN1 : GND
 
const char ssid[] = "ESP-WallBot";  //  your network SSID (name)
const char pass[] = "esp8266ap";  // your network password
 
WiFiUDP udp;
unsigned int localPort = 10000;
const int PACKET_SIZE = 256;
char packetBuffer[PACKET_SIZE];
int status = WL_IDLE_STATUS;
int prev_S=128;

Motor *left_track;
Motor *right_track;

void setup() {
  Serial.begin(115200);
  while (!Serial) {
    ; // wait for serial port to connect. Needed for Leonardo only
  }

  WiFi.softAP(ssid, pass);
  IPAddress myIP = WiFi.softAPIP();

  Serial.print("AP IP address: ");
  Serial.println(myIP);
 
  Serial.println("Starting UDP");
  udp.begin(localPort);
  Serial.print("Local port: ");
  Serial.println(udp.localPort());

  left_track = new Motor(Left_PWM, Left_FWD, Left_REV);
  right_track = new Motor(Rght_PWM, Rght_FWD, Rght_REV);
  left_track->Stop();
  right_track->Stop();
}


void loop() {
  int rlen, val_V=0,val_S=128;
  
  while (1) {
    rlen = udp.parsePacket();
    if(rlen<10) {
      delay(1);
      continue;
    }
     
    udp.read(packetBuffer, (rlen > PACKET_SIZE) ? PACKET_SIZE : rlen);

    val_S=packetBuffer[5];
    if(val_S!=prev_S) {
      //Right analogue y-axis
      left_track->ChangeSpeed(val_S);
      right_track->ChangeSpeed(val_S);
      prev_S=val_S;
    }
    
    val_V=packetBuffer[1];
    if(val_V) {
      switch (val_V) {
        case 1://Left cross up
          left_track->ChangeDirection((boolean)FORWARD);
          right_track->ChangeDirection((boolean)FORWARD);
          break;
        case 2://Left cross down
          left_track->ChangeDirection((boolean)REVERSE);
          right_track->ChangeDirection((boolean)REVERSE);
          break;
        case 4://Left cross right
          left_track->ChangeDirection((boolean)REVERSE);
          right_track->ChangeDirection((boolean)FORWARD);
          break;
        case 8://Left cross right
          left_track->ChangeDirection((boolean)FORWARD);
          right_track->ChangeDirection((boolean)REVERSE);
          break;
      }
      left_track->Rotate();
      right_track->Rotate();
      
    } else {
      //Release button
      left_track->Stop();
      right_track->Stop();
      
    }
    /*
    for(int i=0;i<rlen;i++) {
      Serial.printf("%d",packetBuffer[i]);
    }
    Serial.printf("\n");
    */
    //delay(10);
  }
}
